"""Added task.autoDelete time

Peek Plugin Database Migration Script

Revision ID: 297359a078eb
Revises: db5936c4d50d
Create Date: 2017-03-12 13:32:14.745526

"""

# revision identifiers, used by Alembic.
revision = "297359a078eb"
down_revision = "db5936c4d50d"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "Task",
        sa.Column("autoDeleteDateTime", sa.DateTime(), nullable=True),
        schema="pl_inbox",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("Task", "autoDeleteDateTime", schema="pl_inbox")
    # ### end Alembic commands ###
